@@ -1,9 +1,19 @@
 package PPerl;
 
 use strict;
-use vars qw($VERSION);
+use vars qw($VERSION @ISA @EXPORT_OK);
+
+require DynaLoader;
+require Exporter;
+
+$VERSION = '0.14';
+
+@ISA = qw(Exporter DynaLoader);
+@EXPORT_OK = qw( s_pipe send_fd recv_fd dup2 writen close_fd read_byte read_int );
+
+bootstrap PPerl $VERSION;
+
 
-$VERSION = '0.13';
 
 1;
 __END__
